@@ -92,10 +92,13 @@ class ClusterRunner(BaseRunner):
         :return res:
         """
         res = {}
+        if verbose: 
+            print('df', df)
+            print('pc_id', pc_id)
         if not out_of_core:
             df3 = merge_cluster_ids(df, pc_id, idx_var)
         else: 
-            pc_id = pc_id['PC_ID']
+            pc_id = pc_id[[idx_var,'PC_ID']]
             df3 = merge_cluster_ids(df, pc_id, idx_var)
         if verbose: print('Merged data with pc_ids...', df3)
         res['data'] = df3
